;; Generated package description from forgejo.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "forgejo" "0.1.2.0.20260430.191702" "Emacs Forgejo Front-end" '((emacs "29.1") (keymap-popup "0.2.1")) :commit "f3bc5f539e3e28bfc2d785ed4f8888f03d324db3" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("tools" "vc" "git" "forgejo") :url "https://codeberg.org/thanosapollo/emacs-forgejo")
